@@ -4,17 +4,22 @@ __all__ = ('get_version')
 
 from os.path import dirname, isdir, join
 import re
-from subprocess import CalledProcessError, check_output
+from subprocess import Popen, PIPE
 
 version_re = re.compile('^Version: (.+)$', re.M)
 
 def get_version():
-    if isdir(join(dirname(__file__), '.git')):
+    d = dirname(__file__)
+
+    if isdir(join(d, '.git')):
         # Get the version using "git describe".
         cmd = 'git describe --tags --match [0-9]*'.split()
         try:
-            version = check_output(cmd).decode().strip()
-        except CalledProcessError:
+            proc = Popen(cmd, stdout=PIPE)
+            version = proc.communicate()[0].decode().strip()
+            if proc.returncode != 0:
+                raise OSError()
+        except OSError:
             print('Unable to get version number from git tags')
             exit(1)
 
@@ -24,7 +29,7 @@ def get_version():
 
     else:
         # Extract the version from the PKG-INFO file.
-        with open('PKG-INFO') as f:
+        with open(join(d, 'PKG-INFO')) as f:
             version = version_re.search(f.read()).group(1)
 
     return version
